==> ui_ex-0.1.3.tar.gz: lib/src/material/theme_data_ex.dart <==
part of ui_ex;
// ignore_for_file: deprecated_member_use

/// 材质主题数据
/// ThemeData
extension MaterialThemeDataEx<T extends Color?> on T {
  /// ThemeData
  ThemeData themeData({
    Brightness? brightness,
    VisualDensity? visualDensity,
    MaterialColor? primarySwatch,
    Brightness? primaryColorBrightness,
    Color? primaryColorLight,
    Color? primaryColorDark,
    Color? accentColor,
    Brightness? accentColorBrightness,
    Color? canvasColor,
    Color? shadowColor,
    Color? scaffoldBackgroundColor,
    Color? bottomAppBarColor,
    Color? cardColor,
    Color? dividerColor,
    Color? focusColor,
    Color? hoverColor,
    Color? highlightColor,
    Color? splashColor,
    InteractiveInkFeatureFactory? splashFactory,
    Color? selectedRowColor,
    Color? unselectedWidgetColor,
    Color? disabledColor,
    Color? buttonColor,
    ButtonThemeData? buttonTheme,
    ToggleButtonsThemeData? toggleButtonsTheme,
    Color? secondaryHeaderColor,
    Color? textSelectionColor,
    Color? cursorColor,
    Color? textSelectionHandleColor,
    Color? backgroundColor,
    Color? dialogBackgroundColor,
    Color? indicatorColor,
    Color? hintColor,
    Color? errorColor,
    Color? toggleableActiveColor,
    String? fontFamily,
    TextTheme? textTheme,
    TextTheme? primaryTextTheme,
    TextTheme? accentTextTheme,
    InputDecorationTheme? inputDecorationTheme,
    IconThemeData? iconTheme,
    IconThemeData? primaryIconTheme,
    IconThemeData? accentIconTheme,
    SliderThemeData? sliderTheme,
    TabBarTheme? tabBarTheme,
    TooltipThemeData? tooltipTheme,
    CardTheme? cardTheme,
    ChipThemeData? chipTheme,
    TargetPlatform? platform,
    MaterialTapTargetSize? materialTapTargetSize,
    bool? applyElevationOverlayColor,
    PageTransitionsTheme? pageTransitionsTheme,
    AppBarTheme? appBarTheme,
    ScrollbarThemeData? scrollbarTheme,
    BottomAppBarTheme? bottomAppBarTheme,
    ColorScheme? colorScheme,
    DialogTheme? dialogTheme,
    FloatingActionButtonThemeData? floatingActionButtonTheme,
    NavigationBarThemeData? navigationBarTheme,
    NavigationRailThemeData? navigationRailTheme,
    Typography? typography,
    NoDefaultCupertinoThemeData? cupertinoOverrideTheme,
    SnackBarThemeData? snackBarTheme,
    BottomSheetThemeData? bottomSheetTheme,
    PopupMenuThemeData? popupMenuTheme,
    MaterialBannerThemeData? bannerTheme,
    DividerThemeData? dividerTheme,
    ButtonBarThemeData? buttonBarTheme,
    BottomNavigationBarThemeData? bottomNavigationBarTheme,
    TimePickerThemeData? timePickerTheme,
    TextButtonThemeData? textButtonTheme,
    ElevatedButtonThemeData? elevatedButtonTheme,
    OutlinedButtonThemeData? outlinedButtonTheme,
    TextSelectionThemeData? textSelectionTheme,
    DataTableThemeData? dataTableTheme,
    CheckboxThemeData? checkboxTheme,
    RadioThemeData? radioTheme,
    SwitchThemeData? switchTheme,
    ProgressIndicatorThemeData? progressIndicatorTheme,
    DrawerThemeData? drawerTheme,
    ListTileThemeData? listTileTheme,
    bool? fixTextFieldOutlineLabel,
    bool? useTextSelectionTheme,
    AndroidOverscrollIndicator? androidOverscrollIndicator,
  }) =>
      ThemeData(
        brightness: brightness,
        visualDensity: visualDensity,
        primarySwatch: primarySwatch,
        primaryColor: this,
        primaryColorBrightness: primaryColorBrightness,
        primaryColorLight: primaryColorLight,
        primaryColorDark: primaryColorDark,
        accentColor: accentColor,
        accentColorBrightness: accentColorBrightness,
        canvasColor: canvasColor,
        shadowColor: shadowColor,
        scaffoldBackgroundColor: scaffoldBackgroundColor,
        bottomAppBarColor: bottomAppBarColor,
        cardColor: cardColor,
        dividerColor: dividerColor,
        focusColor: focusColor,
        hoverColor: hoverColor,
        highlightColor: highlightColor,
        splashColor: splashColor,
        splashFactory: splashFactory,
        selectedRowColor: selectedRowColor,
        unselectedWidgetColor: unselectedWidgetColor,
        disabledColor: disabledColor,
        buttonColor: buttonColor,
        buttonTheme: buttonTheme,
        toggleButtonsTheme: toggleButtonsTheme,
        secondaryHeaderColor: secondaryHeaderColor,
        textSelectionColor: textSelectionColor,
        cursorColor: cursorColor,
        textSelectionHandleColor: textSelectionHandleColor,
        backgroundColor: backgroundColor,
        dialogBackgroundColor: dialogBackgroundColor,
        indicatorColor: indicatorColor,
        hintColor: hintColor,
        errorColor: errorColor,
        toggleableActiveColor: toggleableActiveColor,
        fontFamily: fontFamily,
        textTheme: textTheme,
        primaryTextTheme: primaryTextTheme,
        accentTextTheme: accentTextTheme,
        inputDecorationTheme: inputDecorationTheme,
        iconTheme: iconTheme,
        primaryIconTheme: primaryIconTheme,
        accentIconTheme: accentIconTheme,
        sliderTheme: sliderTheme,
        tabBarTheme: tabBarTheme,
        tooltipTheme: tooltipTheme,
        cardTheme: cardTheme,
        chipTheme: chipTheme,
        platform: platform,
        materialTapTargetSize: materialTapTargetSize,
        applyElevationOverlayColor: applyElevationOverlayColor,
        pageTransitionsTheme: pageTransitionsTheme,
        appBarTheme: appBarTheme,
        scrollbarTheme: scrollbarTheme,
        bottomAppBarTheme: bottomAppBarTheme,
        colorScheme: colorScheme,
        dialogTheme: dialogTheme,
        floatingActionButtonTheme: floatingActionButtonTheme,
        navigationBarTheme: navigationBarTheme,
        navigationRailTheme: navigationRailTheme,
        typography: typography,
        cupertinoOverrideTheme: cupertinoOverrideTheme,
        snackBarTheme: snackBarTheme,
        bottomSheetTheme: bottomSheetTheme,
        popupMenuTheme: popupMenuTheme,
        bannerTheme: bannerTheme,
        dividerTheme: dividerTheme,
        buttonBarTheme: buttonBarTheme,
        bottomNavigationBarTheme: bottomNavigationBarTheme,
        timePickerTheme: timePickerTheme,
        textButtonTheme: textButtonTheme,
        elevatedButtonTheme: elevatedButtonTheme,
        outlinedButtonTheme: outlinedButtonTheme,
        textSelectionTheme: textSelectionTheme,
        dataTableTheme: dataTableTheme,
        checkboxTheme: checkboxTheme,
        radioTheme: radioTheme,
        switchTheme: switchTheme,
        progressIndicatorTheme: progressIndicatorTheme,
        drawerTheme: drawerTheme,
        listTileTheme: listTileTheme,
        fixTextFieldOutlineLabel: fixTextFieldOutlineLabel,
        useTextSelectionTheme: useTextSelectionTheme,
        androidOverscrollIndicator: androidOverscrollIndicator,
      );
}

extension MaterialBasedCupertinoThemeDataEx<T extends ThemeData> on T {
  /// MaterialBasedCupertinoThemeData
  MaterialBasedCupertinoThemeData materialBasedCupertinoThemeData() =>
      MaterialBasedCupertinoThemeData(materialTheme: this);
}

extension MaterialVisualDensityaEx<T extends double> on Tuple2<T?, T?> {
  /// VisualDensity
  VisualDensity visualDensity() =>
      VisualDensity(horizontal: item1 ?? 0.0, vertical: item2 ?? 0.0);
}

==> ui_ex-0.1.10.tar.gz: lib/src/material/theme_data_ex.dart <==
part of ui_ex;

/// 材质主题数据
/// ThemeData
extension MaterialThemeDataEx<T extends Color?> on T {
  /// ThemeData
  ThemeData themeData({
    Brightness? brightness,
    VisualDensity? visualDensity,
    MaterialColor? primarySwatch,
    Brightness? primaryColorBrightness,
    Color? primaryColorLight,
    Color? primaryColorDark,
    // Color? accentColor,
    // Brightness? accentColorBrightness,
    Color? canvasColor,
    Color? shadowColor,
    Color? scaffoldBackgroundColor,
    Color? bottomAppBarColor,
    Color? cardColor,
    Color? dividerColor,
    Color? focusColor,
    Color? hoverColor,
    Color? highlightColor,
    Color? splashColor,
    InteractiveInkFeatureFactory? splashFactory,
    Color? selectedRowColor,
    Color? unselectedWidgetColor,
    Color? disabledColor,
    // Color? buttonColor,
    ButtonThemeData? buttonTheme,
    ToggleButtonsThemeData? toggleButtonsTheme,
    Color? secondaryHeaderColor,
    // Color? textSelectionColor,
    // Color? cursorColor,
    // Color? textSelectionHandleColor,
    Color? backgroundColor,
    Color? dialogBackgroundColor,
    Color? indicatorColor,
    Color? hintColor,
    Color? errorColor,
    Color? toggleableActiveColor,
    String? fontFamily,
    TextTheme? textTheme,
    TextTheme? primaryTextTheme,
    // TextTheme? accentTextTheme,
    InputDecorationTheme? inputDecorationTheme,
    IconThemeData? iconTheme,
    IconThemeData? primaryIconTheme,
    // IconThemeData? accentIconTheme,
    SliderThemeData? sliderTheme,
    TabBarTheme? tabBarTheme,
    TooltipThemeData? tooltipTheme,
    CardTheme? cardTheme,
    ChipThemeData? chipTheme,
    TargetPlatform? platform,
    MaterialTapTargetSize? materialTapTargetSize,
    bool? applyElevationOverlayColor,
    PageTransitionsTheme? pageTransitionsTheme,
    AppBarTheme? appBarTheme,
    ScrollbarThemeData? scrollbarTheme,
    BottomAppBarTheme? bottomAppBarTheme,
    ColorScheme? colorScheme,
    DialogTheme? dialogTheme,
    FloatingActionButtonThemeData? floatingActionButtonTheme,
    NavigationBarThemeData? navigationBarTheme,
    NavigationRailThemeData? navigationRailTheme,
    Typography? typography,
    NoDefaultCupertinoThemeData? cupertinoOverrideTheme,
    SnackBarThemeData? snackBarTheme,
    BottomSheetThemeData? bottomSheetTheme,
    PopupMenuThemeData? popupMenuTheme,
    MaterialBannerThemeData? bannerTheme,
    DividerThemeData? dividerTheme,
    ButtonBarThemeData? buttonBarTheme,
    BottomNavigationBarThemeData? bottomNavigationBarTheme,
    TimePickerThemeData? timePickerTheme,
    TextButtonThemeData? textButtonTheme,
    ElevatedButtonThemeData? elevatedButtonTheme,
    OutlinedButtonThemeData? outlinedButtonTheme,
    TextSelectionThemeData? textSelectionTheme,
    DataTableThemeData? dataTableTheme,
    CheckboxThemeData? checkboxTheme,
    RadioThemeData? radioTheme,
    SwitchThemeData? switchTheme,
    ProgressIndicatorThemeData? progressIndicatorTheme,
    DrawerThemeData? drawerTheme,
    ListTileThemeData? listTileTheme,
    // bool? fixTextFieldOutlineLabel,
    // bool? useTextSelectionTheme,
    AndroidOverscrollIndicator? androidOverscrollIndicator,
  }) =>
      ThemeData(
        brightness: brightness,
        visualDensity: visualDensity,
        primarySwatch: primarySwatch,
        primaryColor: this,
        primaryColorBrightness: primaryColorBrightness,
        primaryColorLight: primaryColorLight,
        primaryColorDark: primaryColorDark,
        // accentColor: accentColor,
        // accentColorBrightness: accentColorBrightness,
        canvasColor: canvasColor,
        shadowColor: shadowColor,
        scaffoldBackgroundColor: scaffoldBackgroundColor,
        bottomAppBarColor: bottomAppBarColor,
        cardColor: cardColor,
        dividerColor: dividerColor,
        focusColor: focusColor,
        hoverColor: hoverColor,
        highlightColor: highlightColor,
        splashColor: splashColor,
        splashFactory: splashFactory,
        selectedRowColor: selectedRowColor,
        unselectedWidgetColor: unselectedWidgetColor,
        disabledColor: disabledColor,
        // buttonColor: buttonColor,
        buttonTheme: buttonTheme,
        toggleButtonsTheme: toggleButtonsTheme,
        secondaryHeaderColor: secondaryHeaderColor,
        // textSelectionColor: textSelectionColor,
        // cursorColor: cursorColor,
        // textSelectionHandleColor: textSelectionHandleColor,
        backgroundColor: backgroundColor,
        dialogBackgroundColor: dialogBackgroundColor,
        indicatorColor: indicatorColor,
        hintColor: hintColor,
        errorColor: errorColor,
        toggleableActiveColor: toggleableActiveColor,
        fontFamily: fontFamily,
        textTheme: textTheme,
        primaryTextTheme: primaryTextTheme,
        // accentTextTheme: accentTextTheme,
        inputDecorationTheme: inputDecorationTheme,
        iconTheme: iconTheme,
        primaryIconTheme: primaryIconTheme,
        // accentIconTheme: accentIconTheme,
        sliderTheme: sliderTheme,
        tabBarTheme: tabBarTheme,
        tooltipTheme: tooltipTheme,
        cardTheme: cardTheme,
        chipTheme: chipTheme,
        platform: platform,
        materialTapTargetSize: materialTapTargetSize,
        applyElevationOverlayColor: applyElevationOverlayColor,
        pageTransitionsTheme: pageTransitionsTheme,
        appBarTheme: appBarTheme,
        scrollbarTheme: scrollbarTheme,
        bottomAppBarTheme: bottomAppBarTheme,
        colorScheme: colorScheme,
        dialogTheme: dialogTheme,
        floatingActionButtonTheme: floatingActionButtonTheme,
        navigationBarTheme: navigationBarTheme,
        navigationRailTheme: navigationRailTheme,
        typography: typography,
        cupertinoOverrideTheme: cupertinoOverrideTheme,
        snackBarTheme: snackBarTheme,
        bottomSheetTheme: bottomSheetTheme,
        popupMenuTheme: popupMenuTheme,
        bannerTheme: bannerTheme,
        dividerTheme: dividerTheme,
        buttonBarTheme: buttonBarTheme,
        bottomNavigationBarTheme: bottomNavigationBarTheme,
        timePickerTheme: timePickerTheme,
        textButtonTheme: textButtonTheme,
        elevatedButtonTheme: elevatedButtonTheme,
        outlinedButtonTheme: outlinedButtonTheme,
        textSelectionTheme: textSelectionTheme,
        dataTableTheme: dataTableTheme,
        checkboxTheme: checkboxTheme,
        radioTheme: radioTheme,
        switchTheme: switchTheme,
        progressIndicatorTheme: progressIndicatorTheme,
        drawerTheme: drawerTheme,
        listTileTheme: listTileTheme,
        // fixTextFieldOutlineLabel: fixTextFieldOutlineLabel,
        // useTextSelectionTheme: useTextSelectionTheme,
        androidOverscrollIndicator: androidOverscrollIndicator,
      );
}

extension MaterialBasedCupertinoThemeDataEx<T extends ThemeData> on T {
  /// MaterialBasedCupertinoThemeData
  MaterialBasedCupertinoThemeData materialBasedCupertinoThemeData() =>
      MaterialBasedCupertinoThemeData(materialTheme: this);
}

extension MaterialVisualDensityaEx<T extends double> on Tuple2<T?, T?> {
  /// VisualDensity
  VisualDensity visualDensity() =>
      VisualDensity(horizontal: item1 ?? 0.0, vertical: item2 ?? 0.0);
}
